@@ -44,6 +44,11 @@ char* PMIx_Info_string(const pmix_info_t *info)
     pmix_status_t rc;
     char *output = NULL;
 
+    if (pmix_globals.init_cntr <= 0) {
+        pmix_bfrops_base_print_info(&output, NULL, (void*)info, PMIX_INFO);
+        return output;
+    }
+
     PMIX_BFROPS_PRINT(rc, pmix_globals.mypeer,
                       &output, NULL,
                       (void*)info, PMIX_INFO);
@@ -58,6 +63,11 @@ char* PMIx_Value_string(const pmix_value_t *value)
     pmix_status_t rc;
     char *output = NULL;
 
+    if (pmix_globals.init_cntr <= 0) {
+        pmix_bfrops_base_print_value(&output, NULL, (void*)value, PMIX_VALUE);
+        return output;
+    }
+
     PMIX_BFROPS_PRINT(rc, pmix_globals.mypeer,
                       &output, NULL,
                       (void*)value, PMIX_VALUE);
